/*
 * mode.h
 *
 *  Created on: Jul 23, 2016
 *      Author: esp8266
 */

#ifndef NODE_H_
#define MODE_H_

// Describes a frequency mode at which a tube resonates. The frequency is period
typedef struct mode
{
	// The value the oscillator was set to when amplitude was measured. Actually
	// period is the duration of one half-wave. Thus the corresponding frequency is (1 / (period *2).
	uint16_t period;

	// Represents the amplitude that was measured when the oscillator was set to period.
	uint16_t amplitude;

	// width is the smallest value where at (period - width) an amplitude was measured that
	// was smaller or equal to (amplitude - SCAN_MODE_HEIGHT).
	// Thus with naively quantifies the 'steepness' of this mode. The smaller width, the
	// steeper the mode. The intention is to describe the 'quality' of the mode.
	uint8_t width;
} mode_t;

#endif /* MODE_H_ */
